==> cscec5b-ecxj-impl-3.0.0-20230509.073540-32-sources.jar: com/ejianc/business/ecxj/vo/NoticeSuplProductVO.java <==
package com.ejianc.business.ecxj.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 比选通知商品实体（明细）
 * 
 * @author generator
 * 
 */
public class NoticeSuplProductVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String noticeId; // 比选通知单据主表主键ID
    private Long tenderProductId; // 比选通知单据主表主键ID
    private String productName; // 商品名称
    private String productSpec; // 规格型号
    private String productUnit; // 计量单位
    private BigDecimal tenderNum; // 招标数量

    private String productPrice; // 云筑网，单价/下浮率
    private String productRate; // 税率，云筑网
    private BigDecimal fillPrice; // 税前单价/下浮率（填报）

    public String getNoticeId() {
        return noticeId;
    }

    public void setNoticeId(String noticeId) {
        this.noticeId = noticeId;
    }
    public Long getTenderProductId() {
        return tenderProductId;
    }

    public void setTenderProductId(Long tenderProductId) {
        this.tenderProductId = tenderProductId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public String getProductSpec() {
        return productSpec;
    }

    public void setProductSpec(String productSpec) {
        this.productSpec = productSpec;
    }
    public String getProductUnit() {
        return productUnit;
    }

    public void setProductUnit(String productUnit) {
        this.productUnit = productUnit;
    }
    public BigDecimal getTenderNum() {
        return tenderNum;
    }

    public void setTenderNum(BigDecimal tenderNum) {
        this.tenderNum = tenderNum;
    }
    public String getProductPrice() {
        return productPrice;
    }

    public void setProductPrice(String productPrice) {
        this.productPrice = productPrice;
    }
    public String getProductRate() {
        return productRate;
    }

    public void setProductRate(String productRate) {
        this.productRate = productRate;
    }
    public BigDecimal getFillPrice() {
        return fillPrice;
    }

    public void setFillPrice(BigDecimal fillPrice) {
        this.fillPrice = fillPrice;
    }
}

==> cscec5b-ecxj-impl-3.0.0-20231122.020216-54-sources.jar: com/ejianc/business/ecxj/vo/NoticeSuplProductVO.java <==
package com.ejianc.business.ecxj.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 比选通知商品实体（明细）
 * 
 * @author generator
 * 
 */
public class NoticeSuplProductVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String noticeId; // 比选通知单据主表主键ID
    private Long tenderProductId; // 比选通知单据主表主键ID
    private String productName; // 商品名称
    private String productSpec; // 规格型号
    private String productUnit; // 计量单位
    private BigDecimal tenderNum; // 招标数量

    private String productPrice; // 云筑网，单价/下浮率
    private String productRate; // 税率，云筑网
    private String productLowerRate; // 集采下浮率，云筑网
    private BigDecimal fillPrice; // 税前单价/下浮率（填报）

    public String getNoticeId() {
        return noticeId;
    }

    public void setNoticeId(String noticeId) {
        this.noticeId = noticeId;
    }
    public Long getTenderProductId() {
        return tenderProductId;
    }

    public void setTenderProductId(Long tenderProductId) {
        this.tenderProductId = tenderProductId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public String getProductSpec() {
        return productSpec;
    }

    public void setProductSpec(String productSpec) {
        this.productSpec = productSpec;
    }
    public String getProductUnit() {
        return productUnit;
    }

    public void setProductUnit(String productUnit) {
        this.productUnit = productUnit;
    }
    public BigDecimal getTenderNum() {
        return tenderNum;
    }

    public void setTenderNum(BigDecimal tenderNum) {
        this.tenderNum = tenderNum;
    }
    public String getProductPrice() {
        return productPrice;
    }

    public void setProductPrice(String productPrice) {
        this.productPrice = productPrice;
    }
    public String getProductRate() {
        return productRate;
    }

    public void setProductRate(String productRate) {
        this.productRate = productRate;
    }

    public String getProductLowerRate() {
        return productLowerRate;
    }

    public void setProductLowerRate(String productLowerRate) {
        this.productLowerRate = productLowerRate;
    }

    public BigDecimal getFillPrice() {
        return fillPrice;
    }

    public void setFillPrice(BigDecimal fillPrice) {
        this.fillPrice = fillPrice;
    }
}
